#include "STools.h"
#include <Arduino.h>

/*
This library contains various convenient solutions for various tasks.
The name STools stands for Smart Tools, which translates as "Useful Tools."
At the moment the library is in the process of development and is actively expanding.
Developed: Suhodolov Michael Mail: skaldek@mail.ru
*/


STools::STools(){
	
}
STools::STools(int pin){
	_PIN = pin;
	pinMode(pin, INPUT_PULLUP);
}
STools::STools(float min, float max){
	_MIN = min;
	_MAX = max;
}
STools::STools(int pin, int samples, int bcoeff){
	_PIN = pin;
	_samples = samples;
	_bcoeff = bcoeff;	
}

String STools::printLink(){

	  if(Serial.available()){
       ip = Serial.readStringUntil('\n');
  Serial.println("Link accepted!");

}
return ip;
}

bool STools::isPressed(){
STools::BPress();
return button_flag;
}

bool STools::isHold(){
STools::BPress();
return hold_flag;
}

void STools::BPress(){
button = !digitalRead(_PIN);
if(button == 1 && button_flag == 0 && millis() - lastpresstime > 200){
  button_flag = 1;
  lastpresstime = millis();
}
if(button == 0 && button_flag == 1 ){
  button_flag = 0;
  hold_flag = 0;
}
if(button == 1 && button_flag == 1 && millis() - lastpresstime > 1000){
  hold_flag = 1;
  lastpresstime = millis();
}
}

float STools::tempC(){

for (i=0; i< _samples; i++) {
_samplesarr[i] = analogRead(_PIN);
delay(10);
}

average = 0;
for (i=0; i< _samples; i++) {
average += _samplesarr[i];
}

average /= _samples;
average = 1023 / average - 1;
average = 10000 / average;

temperature = average / 10000;
temperature = log(temperature);
temperature /= _bcoeff;
temperature += 1.0 / (25 + 273.15);
temperature = 1.0 / temperature;
temperature -= 273.15;
return temperature;
}

float STools::tempF(){
	return (STools::tempC() * 9/5) + 32;
}

float STools::readVcc(){
  #if defined(__AVR_ATmega32U4__) || defined(__AVR_ATmega1280__) || defined(__AVR_ATmega2560__)
    ADMUX = _BV(REFS0) | _BV(MUX4) | _BV(MUX3) | _BV(MUX2) | _BV(MUX1);
  #elif defined (__AVR_ATtiny24__) || defined(__AVR_ATtiny44__) || defined(__AVR_ATtiny84__)
    ADMUX = _BV(MUX5) | _BV(MUX0);
  #elif defined (__AVR_ATtiny25__) || defined(__AVR_ATtiny45__) || defined(__AVR_ATtiny85__)
    ADMUX = _BV(MUX3) | _BV(MUX2);
  #else
    ADMUX = _BV(REFS0) | _BV(MUX3) | _BV(MUX2) | _BV(MUX1);
  #endif  

  delay(75);
  ADCSRA |= _BV(ADSC);
  while (bit_is_set(ADCSRA,ADSC));

  lowVcc  = ADCL;  
  highVcc = ADCH;

  resultVcc = (highVcc<<8) | lowVcc;

  resultVcc = 1125300L / resultVcc;
  return resultVcc/1000;
}

int STools::readBattery(){
	batteryP = STools::readVcc();
	batteryP = (batteryP - _MIN) * (100 - 0) / (_MAX - _MIN) + 0;
	batteryP = constrain(batteryP, 0, 100);
	return batteryP;
}